@@ -17,6 +17,7 @@ bbd.design <- function(nfactors, ncenter=4, factor.names = NULL, default.levels=
          warning("Box-Behnken designs can only be blocked in case of 4 or 5 factors. No blocking was done.")
          block.name <- NULL
          }
+         if (!is.null(block.name)) block.name <- make.names(block.name)
     if (is.character(factor.names)){
         if (!length(factor.names)==nfactors) stop("mismatch between nfactors and factor.names")
         if (!all(unique(factor.names)==factor.names)) stop("duplicate factor names")
@@ -33,6 +34,9 @@ bbd.design <- function(nfactors, ncenter=4, factor.names = NULL, default.levels=
     for (i in 1:nfactors) if (identical(factor.names[[i]],"")) factor.names[[i]] <- default.levels
     if (is.list(factor.names) & !length(unique(names(factor.names)))==nfactors)
             names(factor.names) <- Letters[1:nfactors]
+    ## make all factor names valid R names
+    names(factor.names) <- make.names(names(factor.names), unique=TRUE)
+
 
     if (randomize & !is.null(seed)) set.seed(seed)
     aus <- bbd(nfactors, n0=ncenter, 
@@ -49,7 +53,7 @@ bbd.design <- function(nfactors, ncenter=4, factor.names = NULL, default.levels=
     run.order(design) <- data.frame(run.no.in.std.order=rownames(aus), run.no=1:nrow(aus), run.no.std.rp=rownames(aus))
     di <- list(type="bbd", nruns=nrow(design), nfactors=nfactors, factor.names=factor.names, quantitative=rep(TRUE, nfactors))
     if (!is.null(block.name)){ blocklist <- list(nblocks=if(nfactors==4) 3 else 2,
-               blocksize=if(nfactors==4) 12 else 24, block.name=block.name)
+               blocksize=if(nfactors==4) 12 else 24, block.name=block.name, bbreps=1, wbreps=1)
           di$type <- "bbd.blocked"
           di <- c(di,blocklist)
           }
